==> mbeancmd-core-2.0.1-sources.jar: org/ow2/jasmine/monitoring/mbeancmd/sampling/Sampler.java <==
/**
 * JASMINe
 * Copyright (C) 2005-2007 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Sampler.java 55 2007-12-17 16:03:02Z tokmensa $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.mbeancmd.sampling;

import java.io.PrintStream;

import javax.management.MBeanServerConnection;
import javax.management.ObjectName;

import org.ow2.jasmine.monitoring.mbeancmd.context.JmxContext;

/**
 * Base class for all sampler classes.
 */
public abstract class Sampler {
    /**
     * Creates the Sampler using a JMX URL.
     *
     * @param urlString
     *            JMX URL.
     */
    public Sampler(final JmxContext context) {
        this.context = context;
    }

    /**
     * @return Connection to MBean server. Will return existing instance if
     *         already connected, and try to connect if no connection exists.
     *         Returns null on failure.
     */
    protected final MBeanServerConnection getMBeanServerConnection() {
        return this.context.getJmxap().getMBeanServerConnection();
    }

    protected void releaseMbeanServerConnection() {
        this.context.getJmxap().releaseMBeanServerConnection();
    }

    /**
     * Gets the list of object names that match a given object name prototype.
     *
     * @param onProto
     *            Object name filtering pattern to use.
     *
     * @return All objects that match onProto.
     */
    protected final ObjectName[] queryON(final String onProto) {
        ObjectName[] ons = null;
        try {
            //Set onSet = null;
            MBeanServerConnection cnx = getMBeanServerConnection();

            this.context.setOnames(cnx.queryNames(new ObjectName(onProto), null));
            if (!this.context.getOnames().isEmpty()) {
                ons = (ObjectName[]) this.context.getOnames().toArray(new ObjectName[this.context.getOnames().size()]);
                for (int i = 0; i < ons.length; i++) {
                    System.out.println("Found ObjectName in server " + context.getName() + " (" + context.getServer() + " on domain "
                            + context.getDomain() + "): " + ons[i]);
                }
            }
        } catch (Exception e) {
            e.printStackTrace(System.err);
        }
        return ons;
    }

    /**
     * @return Default Object name filtering pattern for this sampler. If null,
     *         we'll consider that the Sampler doesn't have one default object
     *         name filter.
     */
    protected abstract String getDefaultOn();

    /**
     * @return Object name filtering pattern.
     */
    protected String getOn() {
        return this.objectName;
    }

    /**
     * @param onProto
     *            Object name filtering pattern to set.
     */
    public void setOn(final String onProto) {
        this.objectName = onProto;
    }

    /**
     * Initialize the sampler, itself called by
     * {@link Sampler#process(long, PrintStream)}.
     *
     * This implementation will fill {@link Sampler#oNames} based on the object
     * name filter set using {@link Sampler#setOn(String)}.
     *
     * If no filter was set before calling this method, will call set object
     * name to {@link Sampler#getDefaultOn()}.
     *
     * If {@link Sampler#getDefaultOn()} has returned null, then
     * {@link Sampler#oNames} will remain null.
     */
    public void init() {

        if(getOn()==null) {
            setOn(getDefaultOn());
        }

        this.queryON(getOn());
    }

    /**
     * Samples data based on a previous sample.
     *
     * @param previous
     *            Previous sample.
     *
     * @return Sampled data,
     * @see SampleData#compute(SampleData)
     */
    public final SampleData sample(final SampleData previous) {
        SampleData data = newSampleData();

        try {
            data.setSampleTime(System.currentTimeMillis());
            poll(data);
            if (data.isValid()) {
                data.compute(previous);
            }
        } catch (Exception e) {
            e.printStackTrace(System.err);
        }

        if (data.isValid()) {
            return data;
        } else {
            return null;
        }
    }

    /**
     * @return Name set for the server in the jmxurls.properties file.
     */
    public String getName() {
        return this.context.getName();
    }

    /**
     * @return Server name.
     */
    public String getServer() {
        return this.context.getServer();
    }

    /**
     * @return Server's domain name.
     */
    public String getDomain() {
        return this.context.getDomain();
    }

    /**
     * @return New sample data.
     */
    protected abstract SampleData newSampleData();

    /**
     * Poll based on a previous sample.
     *
     * @param prev
     *            Previous sample.
     *
     * @return Resulting data.
     */
    protected abstract SampleData poll(final SampleData prev);

    /**
     * Object name.
     */
    private String objectName = null;

    /**
     * context of the sampler
     */
    protected JmxContext context;

}

==> mbeancmd-core-2.1.2-sources.jar: org/ow2/jasmine/monitoring/mbeancmd/sampling/Sampler.java <==
/**
 * JASMINe
 * Copyright (C) 2005-2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Sampler.java 5950 2010-01-18 14:27:56Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.mbeancmd.sampling;

import java.io.PrintStream;

import javax.management.MBeanServerConnection;
import javax.management.ObjectName;

import org.ow2.jasmine.monitoring.mbeancmd.context.JmxContext;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * Base class for all sampler classes.
 */
public abstract class Sampler {

    /**
     * Logger.
     */
    protected Log logger = LogFactory.getLog(this.getClass());

    /**
     * Creates the Sampler using a JMX URL.
     *
     * @param urlString
     *            JMX URL.
     */
    public Sampler(final JmxContext context) {
        this.context = context;
    }

    /**
     * @return Connection to MBean server. Will return existing instance if
     *         already connected, and try to connect if no connection exists.
     *         Returns null on failure.
     */
    protected final MBeanServerConnection getMBeanServerConnection() {
        return this.context.getJmxap().getMBeanServerConnection();
    }

    protected void releaseMbeanServerConnection() {
        this.context.getJmxap().releaseMBeanServerConnection();
    }

    /**
     * Gets the list of object names that match a given object name prototype.
     *
     * @param onProto
     *            Object name filtering pattern to use.
     *
     * @return All objects that match onProto.
     */
    protected final ObjectName[] queryON(final String onProto) {
        ObjectName[] ons = null;
        try {
            //Set onSet = null;
            MBeanServerConnection cnx = getMBeanServerConnection();

            this.logger.debug("MBean discovery: starting search in server {0} ({1}) pattern {2}", context.getName(),
                context.getServer(), onProto);

            this.context.setOnames(cnx.queryNames(new ObjectName(onProto), null));
            if (!this.context.getOnames().isEmpty()) {
                this.logger.debug("MBean discovery: succesful probe, {0}", context.getName());
                ons = (ObjectName[]) this.context.getOnames().toArray(new ObjectName[this.context.getOnames().size()]);
                for (int i = 0; i < ons.length; i++) {
                    this.logger.debug("MBean discovery: Found ObjectName in server {0} ({1} on domain {2}): {3}",
                        context.getName(), context.getServer(), context.getDomain(), ons[i]);
                }
            }

            this.logger.debug("MBean discovery: search complete in server {0} ({1}) pattern {2}", context.getName(),
                context.getServer(), onProto);
        } catch (Exception e) {
            this.logger.warn("MBean discovery: failed probe, target {0} ({1}) pattern {2}\n", context.getName(),
                context.getServer(), onProto);
            this.logger.warn("Exception {0}\n", e.getMessage());
        }
        return ons;
    }

    /**
     * @return Default Object name filtering pattern for this sampler. If null,
     *         we'll consider that the Sampler doesn't have one default object
     *         name filter.
     */
    protected abstract String getDefaultOn();

    /**
     * @return Object name filtering pattern.
     */
    protected String getOn() {
        return this.objectName;
    }

    /**
     * @param onProto
     *            Object name filtering pattern to set.
     */
    public void setOn(final String onProto) {
        this.objectName = onProto;
    }

    /**
     * Initialize the sampler, itself called by
     * {@link Sampler#process(long, PrintStream)}.
     *
     * This implementation will fill {@link Sampler#oNames} based on the object
     * name filter set using {@link Sampler#setOn(String)}.
     *
     * If no filter was set before calling this method, will call set object
     * name to {@link Sampler#getDefaultOn()}.
     *
     * If {@link Sampler#getDefaultOn()} has returned null, then
     * {@link Sampler#oNames} will remain null.
     */
    public void init() {

        if(getOn()==null) {
            setOn(getDefaultOn());
        }

        this.queryON(getOn());
    }

    /**
     * Samples data based on a previous sample.
     *
     * @param previous
     *            Previous sample.
     *
     * @return Sampled data,
     * @see SampleData#compute(SampleData)
     */
    public final SampleData sample(final SampleData previous) {
        SampleData data = newSampleData();

        try {
            data.setSampleTime(System.currentTimeMillis());
            poll(data);
            if (data.isValid()) {
                data.compute(previous);
            }
        } catch (Exception e) {
            this.logger.error("Failed sampling", e);
        }

        if (data.isValid()) {
            return data;
        } else {
            return null;
        }
    }

    /**
     * @return Name set for the server in the jmxurls.properties file.
     */
    public String getName() {
        return this.context.getName();
    }

    /**
     * @return
     */
    public String getJmxUrl() {
        return this.context.getJmxUrl();
    }

    /**
     * @return Server name.
     */
    public String getServer() {
        return this.context.getServer();
    }

    /**
     * @return Server's domain name.
     */
    public String getDomain() {
        return this.context.getDomain();
    }

    /**
     * @return New sample data.
     */
    protected abstract SampleData newSampleData();

    /**
     * Poll based on a previous sample.
     *
     * @param prev
     *            Previous sample.
     *
     * @return Resulting data.
     */
    protected abstract SampleData poll(final SampleData prev);

    /**
     * Object name.
     */
    private String objectName = null;

    /**
     * context of the sampler
     */
    protected JmxContext context;

}
